using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

public class MyPointControl : Control {
	private System.ComponentModel.Container components = null;
	private MyPoint mp;
	public MyPointControl() {
		InitializeComponent();
		mp = new MyPoint(0, 0);
	}
	protected override void Dispose( bool disposing ) {
		if (disposing)
			if (components != null) 
				components.Dispose();
		base.Dispose(disposing);
	}
	private void InitializeComponent() {
		components = new System.ComponentModel.Container();
	}
	public MyPoint Point {
		get {
			return mp;
		}
		set {
			mp = value;
			Refresh();
		}
	}
	MyPoint GetPoint() {
		Point p = PointToClient(Control.MousePosition);
		int x = p.X, y = p.Y, out_x, out_y;
		float half = Width / 2;
		out_x = (int)((((float)x - half) / half) * (float)MAX);
		half = Height / 2;
		out_y = (int)((((float)y - half) / half) * (float)MAX);
		return new MyPoint(out_x, -out_y);
	}
	protected override void OnClick(EventArgs e) {
		mp = GetPoint();
		Refresh();
		base.OnClick(e);
	}
	const int MAX = 100; 
	const int POINT_SIZE = 6;
	Point Convert(Point p) {
		int x = p.X, y = p.Y, out_x, out_y;
		float half = Width / 2;
		out_x = (int)(half * (1.0F - (float)-x / (float)MAX));
		half = Height / 2;
		out_y = (int)(half * (1.0F - (float)y / (float)MAX));
		return new Point(out_x, out_y);
	}
	void DrawPoint(Graphics g) {
		Point p = Convert(new Point(mp.X, mp.Y));
		SolidBrush brush = new SolidBrush(Color.Red);
		g.FillEllipse(brush, p.X - (POINT_SIZE / 2), p.Y - (POINT_SIZE / 2), POINT_SIZE, POINT_SIZE);
	}
	void DrawGrid(Graphics g) {
		Point[,] grids = {
			{new Point(50, 100), new Point(50, -100),},
			{new Point(-50, 100), new Point(-50, -100),},
			{new Point(100, 50), new Point(-100, 50),},
			{new Point(100, -50), new Point(-100, -50),},
		};
		Point[,] origin_grids = {
			{new Point(100, 0), new Point(-100, 0),},
			{new Point(0, 100), new Point(0, -100),},
		};
		const int start = 0, end = 1;
		Pen grid_pen = new Pen(Color.Blue), origin_pen = new Pen(Color.Black);
		for (int i = 0; i < grids.GetLength(0); i++)
			g.DrawLine(grid_pen, Convert(grids[i, start]), Convert(grids[i, end]));
		for (int i = 0; i < origin_grids.GetLength(0); i++)
			g.DrawLine(origin_pen, Convert(origin_grids[i, start]), Convert(origin_grids[i, end]));
	}
	protected override void OnPaint(PaintEventArgs e) {
		Graphics g = e.Graphics;
		DrawGrid(g);
		DrawPoint(g);
		base.OnPaint(e);
	}
}
